@@ -901,6 +901,7 @@ class TestCase(unittest.TestCase):
             with head():
                 with title():
                     Text('Hello World')
+                    # div()
             with body():
                 with div(_class="container"):
                     with div(_class="row"):
@@ -1002,12 +1003,88 @@ class TestCase(unittest.TestCase):
             
         print(d)
         
-        mydialog = HTMLDialogElement()
-        print(mydialog)
-        print(str(mydialog))
+        # mydialog = HTMLDialogElement()
+        # print(mydialog)
+        # print(str(mydialog))
             
         # assert str(d) == '<html><dialog open>hello<form method="dialog" action="close"><button>close</button></form></dialog></html>'
 
 
+    def test_every_tag(self):
+        assert str(html()) == '<html></html>'
+        assert str(head()) == '<head></head>'
+        assert str(body()) == '<body></body>'
+        assert str(title()) == '<title></title>'
+        # print(str(meta()))
+        assert str(meta()) == '<meta/>'
+        assert str(link()) == '<link/>'  # TODO - in html5 i think slash no longer required? (one for config when thats setup)
+        assert str(style()) == '<style></style>'
+        assert str(script()) == '<script></script>'
+        assert str(noscript()) == '<noscript></noscript>'
+        assert str(iframe()) == '<iframe></iframe>'
+        # assert str(frame()) == '<frame></frame>'
+        # assert str(frameset()) == '<frameset></frameset>'
+        # assert str(noframes()) == '<noframes></noframes>'
+        assert str(b()) == '<b></b>'
+        assert str(i()) == '<i></i>'
+        assert str(u()) == '<u></u>'
+        assert str(s()) == '<s></s>'
+        assert str(strike()) == '<strike></strike>'
+        assert str(strong()) == '<strong></strong>'
+        assert str(em()) == '<em></em>'
+        assert str(small()) == '<small></small>'
+        # assert str(big()) == '<big></big>'
+        assert str(sub()) == '<sub></sub>'
+        assert str(sup()) == '<sup></sup>'
+        # assert str(tt()) == '<tt></tt>'
+        assert str(code()) == '<code></code>'
+        assert str(pre()) == '<pre></pre>'
+        assert str(blockquote()) == '<blockquote></blockquote>'
+        assert str(address()) == '<address></address>'
+        assert str(div()) == '<div></div>'
+        assert str(span()) == '<span></span>'
+        assert str(a()) == '<a></a>'
+        assert str(p()) == '<p></p>'
+        assert str(h1()) == '<h1></h1>'
+        assert str(h2()) == '<h2></h2>'
+        assert str(h3()) == '<h3></h3>'
+        assert str(h4()) == '<h4></h4>'
+        assert str(h5()) == '<h5></h5>'
+        assert str(h6()) == '<h6></h6>'
+        assert str(ul()) == '<ul></ul>'
+        assert str(ol()) == '<ol></ol>'
+        assert str(li()) == '<li></li>'
+        assert str(dl()) == '<dl></dl>'
+        assert str(dt()) == '<dt></dt>'
+        assert str(dd()) == '<dd></dd>'
+        assert str(figure()) == '<figure></figure>'
+        assert str(figcaption()) == '<figcaption></figcaption>'
+        assert str(main()) == '<main></main>'
+        assert str(article()) == '<article></article>'
+        assert str(aside()) == '<aside></aside>'
+        assert str(header()) == '<header></header>'
+        assert str(footer()) == '<footer></footer>'
+        assert str(nav()) == '<nav></nav>'
+        assert str(section()) == '<section></section>'
+        assert str(dialog()) == '<dialog></dialog>'
+        assert str(details()) == '<details></details>'
+        assert str(summary()) == '<summary></summary>'
+        assert str(menu()) == '<menu></menu>'
+        assert str(menuitem()) == '<menuitem></menuitem>'
+        # assert str(command()) == '<command></command>'
+        assert str(output()) == '<output></output>'
+        assert str(progress()) == '<progress></progress>'
+        assert str(meter()) == '<meter></meter>'
+        # assert str(time()) == '<time></time>'
+        # assert str(keygen()) == '<keygen></keygen>'
+        assert str(output()) == '<output></output>'
+        assert str(progress()) == '<progress></progress>'
+        assert str(meter()) == '<meter></meter>'
+        assert str(details()) == '<details></details>'
+        
+
+    # TODO - unit tests the tags of other the markups i.e. mathml, svg etc
+
+
 if __name__ == '__main__':
     unittest.main()
